
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: rikai_sklearn:rikai-sklearn

from setuptools import setup

setup(**{
    'install_requires': (
        'rikai==0.1.14',
        'scikit-learn',
    ),
    'license': 'Apache License, Version 2.0',
    'name': 'rikai-sklearn',
    'namespace_packages': (
    ),
    'package_data': {
    },
    'packages': (
        'rikai_sklearn',
        'rikai_sklearn.models',
    ),
    'python_requires': '>=3.7',
    'version': '0.1.1',
})
